@@ -3,13 +3,16 @@ use swc_common::{collections::AHashSet, util::take::Take, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::ExprFactory;
 use swc_ecma_visit::{as_folder, noop_visit_mut_type, Fold, VisitMut, VisitMutWith};
+use swc_trace_macro::swc_trace;
 
 struct ClassStaticBlock;
 
+#[tracing::instrument(level = "trace", skip_all)]
 pub fn static_blocks() -> impl Fold + VisitMut {
     as_folder(ClassStaticBlock)
 }
 
+#[swc_trace]
 impl ClassStaticBlock {
     fn visit_mut_class_for_static_block(&mut self, class: &mut Class) {
         let mut private_names = AHashSet::default();
@@ -82,6 +85,7 @@ impl ClassStaticBlock {
     }
 }
 
+#[swc_trace]
 impl VisitMut for ClassStaticBlock {
     noop_visit_mut_type!();
 
